@@ -3,30 +3,30 @@ import logging
 
 
 class Logger():
-    def __init__(self):
-        self.create_logger()
+    def __init__(self, log_name, log_level):
+        self.log_name = log_name
+        self.log_level = log_level
 
-    def create_logger(self, log_name, log_level):
-        logger = logging.getLogger(log_name)
+    def create_logger(self):
+        logger = logging.getLogger(self.log_name)
 
-        if log_level == 'info':
+        if self.log_level == 'info':
             logger.setLevel(logging.INFO)  
 
-        if log_level == 'warning':
+        if self.log_level == 'warning':
             logger.setLevel(logging.WARNING)  
 
-        if log_level == 'debug':
+        if self.log_level == 'debug':
             logger.setLevel(logging.DEBUG)  
             
         formatter = logging.Formatter(  
             '%(levelname)s:%(module)s:%(message)s')
         
         handler = logging.StreamHandler(sys.stderr)
-        handler.setLevel(logging.INFO)
         
         handler.setFormatter(formatter)
         logger.addHandler(handler) 
-        _logger = logging.LoggerAdapter(logging.getLogger(log_name)) 
+        _logger = logging.LoggerAdapter(logging.getLogger(self.log_name)) 
         return _logger
 
 
